@@ -21,7 +21,6 @@
 #include "thumbnail.h"
 
 #include <stdlib.h>
-#include <unistd.h>
 #ifdef __FreeBSD__
     #include <machine/param.h>
 #endif
@@ -29,6 +28,7 @@
 #ifndef Q_OS_WIN
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#include <unistd.h> // nice()
 #endif
 
 #include <QApplication>
@@ -58,10 +58,10 @@
 
 #include <kaboutdata.h>
 #include <kiconloader.h>
-#include <kde_file.h>
 
 #include <kio/thumbcreator.h>
 #include <kio/thumbsequencecreator.h>
+#include <kio/previewjob.h>
 
 #include <iostream>
 #include <QDirIterator>
@@ -453,7 +453,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
-        m_maxFileSize = globalConfig.readEntry("MaximumSize", 5 * 1024 * 1024); // 5 MByte default
+        m_maxFileSize = globalConfig.readEntry("MaximumSize", qulonglong(5 * 1024 * 1024)); // 5 MByte default
     }
 
     const int tiles = 2; //Count of items shown on each dimension
@@ -663,10 +663,14 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
 {
     if (m_enabledPlugins.isEmpty()) {
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-        m_enabledPlugins = globalConfig.readEntry("Plugins", QStringList()
-                                                             << "imagethumbnail"
-                                                             << "jpegthumbnail"
-                                                             << "videopreview");
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 40, 0)
+        m_enabledPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
+#else
+        // We don't have KF5.40 yet; emulate the behavior of KIO::PreviewJob::defaultPlugins()
+        QStringList defaultPlugins = KIO::PreviewJob::availablePlugins();
+        defaultPlugins.removeAll(QStringLiteral("textthumbnail"));
+        m_enabledPlugins = globalConfig.readEntry("Plugins", defaultPlugins);
+#endif
     }
 
     const QMimeDatabase db;
